<?php
add_settings_field(
    'cp_dropbpx_access_token',
    __('Dropbox access token', 'dropbox_access_token'),
    'cpDropboxAccessTokenRender',
    'cloudprinter',
    'cloudprinter_section',
    ['class' => 'dropbox-access-token-setting-field']
);

function cpDropboxAccessTokenRender()
{
    $dropboxAccessToken = get_option('cp_dropbox_access_token');
    $dropboxAccessTokenError = get_option('cp_dropbox_access_token_error');
    $dropboxUsername = get_option('cp_dropbox_username');
    $dropboxService = new \CloudPrinterPlugin\Services\Storage\DropboxService($dropboxAccessToken);
    $displayDropboxManual = !$dropboxUsername;
    if ($dropboxUsername) {
        try {
            $storageInfo = $dropboxService->getStorageInfo();
            echo "<p>You authorized as " . $dropboxUsername . ". <a href='". get_site_url() ."/wp-admin/options-general.php?page=cloudprinter&dropbox_logout=1'>Logout</a></p>";
            echo "<p>Allocated space: " . formatBytes($storageInfo['allocation']['allocated'])  . "</p>";
            echo "<p>Used space: " . formatBytes($storageInfo['used']) . "</p>";
        } catch (\Exception $e) {
            $displayDropboxManual = true;
            echo '<input name="cp_dropbox_access_token" id="cp_dropbox_access_token" value="' . $dropboxAccessToken . '" class="large-text">';
            echo '<p><small style="color:red">The access token is expired.</small></p>';
        }

    }

    if ($displayDropboxManual) {
        echo '<input name="cp_dropbox_access_token" id="cp_dropbox_access_token" value="' . $dropboxAccessToken . '" class="large-text">';

        if (!empty($dropboxAccessTokenError)) {
            echo '<p><small style="color:red">' . $dropboxAccessTokenError . '</small></p>';
        }

        echo '
                <p>
                    <small>The dropbox as external storage is used for products that support dynamic files. 
                    <br> 
                    <a style="cursor: pointer" id="show-dropbox-steps">Where can I get the Dropbox access token?</a></small>
                </p>
               
                <ol id="dropbox-setup-steps" style="display: none; position: relative; left: -12px;">
                    <li>Go to the <a href="https://www.dropbox.com/developers/apps" target="_blank">Dropbox Developers app console</a></li>
                    <li>Press the blue button \'Create app\'</li>
                    <li>Select an "API"</li>
                    <li>Select type of access - "App folder"</li>
                    <li>Set a unique app-name (eg. [storename]-woocommerce) and press "Create App"</li>
                    <li>Open the app. In the setting tab. Search for the field <i>Chooser / Saver / Embedder domains</i> and write "' . str_replace(["http://", "https://"], "", get_site_url()) . '"</li>
                    <li>In the Permissions tab enable the following scopes: <i>files.content.write, sharing.write, file_requests.read</i></li>  
                    <li>Go back to the settings tab, in the section OAuth 2 set  Access token expiration - <i>"No expiration"</i>, press the button <i>"Generate"</i> and copy the access token.</li>  
                    <li>Go back to WooCommerce, paste the access token, and press <i>"Save changes"</i></li>
                </ol>
            ';
    }
}

function formatBytes($bytes, $precision = 2) {
    $unit = ["B", "KB", "MB", "GB"];
    $exp = floor(log($bytes, 1024)) | 0;
    return round($bytes / (pow(1024, $exp)), $precision).$unit[$exp];
}
